@@ -30,13 +30,17 @@ mkdir $dest
 
 
 cp $src/moment.js $dest
+cp $src/moment.d.ts $dest
 cp $src/package.json $dest
 cp $src/README.md $dest
+cp $src/CHANGELOG.md $dest
 cp $src/LICENSE $dest
 cp -r $src/locale $dest
 cp -r $src/min $dest
+cp -r $src/src $dest && rm -r $dest/src/test
 cp $src/ender.js $dest
 cp $src/package.js $dest
+cp $src/.npmignore $dest
 
 rm -rf $src
 
