@@ -258,3 +258,8 @@ test('weeks year starting sunday format', function (assert) {
     assert.equal(moment([2012, 0, 15]).format('w ww wo'),   '2 02 2η', 'Jan 15 2012 should be week 2');
 });
 
+test('localeData months calls', function (assert) {
+    var jan = moment('2012-01-01');
+    assert.equal(moment.localeData().months(jan),           'Ιανουάριος', 'should return the nominative month name');
+    assert.equal(moment.localeData().months(jan, 'D MMMM'), 'Ιανουαρίου', 'should return the genitive month name');
+});
