@@ -4,6 +4,19 @@ import moment from '../../moment';
 
 module('format');
 
+test('format using constants', function (assert) {
+    var m = moment('2017-09-01T23:40:40.678');
+    assert.equal(m.format(moment.HTML5_FMT.DATETIME_LOCAL), '2017-09-01T23:40', 'datetime local format constant');
+    assert.equal(m.format(moment.HTML5_FMT.DATETIME_LOCAL_SECONDS), '2017-09-01T23:40:40', 'datetime local format constant');
+    assert.equal(m.format(moment.HTML5_FMT.DATETIME_LOCAL_MS), '2017-09-01T23:40:40.678', 'datetime local format constant with seconds and millis');
+    assert.equal(m.format(moment.HTML5_FMT.DATE), '2017-09-01', 'date format constant');
+    assert.equal(m.format(moment.HTML5_FMT.TIME), '23:40', 'time format constant');
+    assert.equal(m.format(moment.HTML5_FMT.TIME_SECONDS), '23:40:40', 'time format constant with seconds');
+    assert.equal(m.format(moment.HTML5_FMT.TIME_MS), '23:40:40.678', 'time format constant with seconds and millis');
+    assert.equal(m.format(moment.HTML5_FMT.WEEK), '2017-W35', 'week format constant');
+    assert.equal(m.format(moment.HTML5_FMT.MONTH), '2017-09', 'month format constant');
+});
+
 test('format YY', function (assert) {
     var b = moment(new Date(2009, 1, 14, 15, 25, 50, 125));
     assert.equal(b.format('YY'), '09', 'YY ---> 09');
@@ -148,6 +161,30 @@ test('toISOString', function (assert) {
     // big negative years
     date = moment.utc('-020123-10-09T20:30:40.678');
     assert.equal(date.toISOString(), '-020123-10-09T20:30:40.678Z', 'ISO8601 format on big negative year');
+
+    //invalid dates
+    date = moment.utc('2017-12-32');
+    assert.equal(date.toISOString(), null, 'An invalid date to iso string is null');
+});
+
+test('toISOString without UTC conversion', function (assert) {
+    var date = moment.utc('2016-12-31T19:53:45.678').utcOffset('+05:30');
+
+    assert.equal(date.toISOString(true), '2017-01-01T01:23:45.678+05:30', 'should output ISO8601 on moment.fn.toISOString');
+
+    // big years
+    date = moment.utc('+020122-12-31T19:53:45.678').utcOffset('+05:30');
+    assert.equal(date.toISOString(true), '+020123-01-01T01:23:45.678+05:30', 'ISO8601 format on big positive year');
+    // negative years
+    date = moment.utc('-000002-12-31T19:53:45.678').utcOffset('+05:30');
+    assert.equal(date.toISOString(true), '-000001-01-01T01:23:45.678+05:30', 'ISO8601 format on negative year');
+    // big negative years
+    date = moment.utc('-020124-12-31T19:53:45.678').utcOffset('+05:30');
+    assert.equal(date.toISOString(true), '-020123-01-01T01:23:45.678+05:30', 'ISO8601 format on big negative year');
+
+    //invalid dates
+    date = moment.utc('2017-12-32').utcOffset('+05:30');
+    assert.equal(date.toISOString(true), null, 'An invalid date to iso string is null');
 });
 
 // See https://nodejs.org/dist/latest/docs/api/util.html#util_custom_inspect_function_on_objects
@@ -211,8 +248,15 @@ test('long years', function (assert) {
     assert.equal(moment.utc().year(-20123).format('YYYYYY'), '-020123', 'big negative year with YYYYYY');
 });
 
+test('toISOString() when 0 year', function (assert) {
+    // https://github.com/moment/moment/issues/3765
+    var date = moment('0000-01-01T21:00:00.000Z');
+    assert.equal(date.toISOString(), '0000-01-01T21:00:00.000Z');
+    assert.equal(date.toDate().toISOString(), '0000-01-01T21:00:00.000Z');
+});
+
 test('iso week formats', function (assert) {
-    // http://en.wikipedia.org/wiki/ISO_week_date
+    // https://en.wikipedia.org/wiki/ISO_week_date
     var cases = {
         '2005-01-02': '2004-53',
         '2005-12-31': '2005-52',
@@ -244,7 +288,7 @@ test('iso week formats', function (assert) {
 });
 
 test('iso week year formats', function (assert) {
-    // http://en.wikipedia.org/wiki/ISO_week_date
+    // https://en.wikipedia.org/wiki/ISO_week_date
     var cases = {
         '2005-01-02': '2004-53',
         '2005-12-31': '2005-52',
@@ -277,7 +321,7 @@ test('iso week year formats', function (assert) {
 });
 
 test('week year formats', function (assert) {
-    // http://en.wikipedia.org/wiki/ISO_week_date
+    // https://en.wikipedia.org/wiki/ISO_week_date
     var cases = {
         '2005-01-02': '2004-53',
         '2005-12-31': '2005-52',
